package com.example.project_musicalquiz

import android.os.Bundle
import androidx.appcompat.app.AppCompatActivity
import androidx.fragment.app.Fragment
import com.example.project_musicalquiz.search.SearchFragment
import com.example.project_musicalquiz.databinding.ActivityMainBinding

/**
 * Main activity of the application.
 * This activity hosts the main UI and handles navigation between different fragments.
 */
class MainActivity : AppCompatActivity() {

    /**
     * View binding instance for the main activity layout.
     */
    private lateinit var binding: ActivityMainBinding

    /**
     * Called when the activity is first created.
     * Initializes the view, sets up the bottom navigation, and loads the initial fragment.
     *
     * @param savedInstanceState If the activity is being re-initialized after
     *     previously being shut down then this Bundle contains the data it most
     *     recently supplied in onSaveInstanceState(Bundle). Otherwise it is null.
     */
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        // Inflate the layout using view binding
        binding = ActivityMainBinding.inflate(layoutInflater)
        setContentView(binding.root)

        // Load the SearchFragment as the initial fragment
        loadFragment(SearchFragment())

        // Set up the bottom navigation listener
        val bottomNav = binding.bottomNavigation
        bottomNav.setOnItemSelectedListener { item ->
            when (item.itemId) {
                R.id.navigation_search -> {
                    // Load the SearchFragment when the search item is selected
                    loadFragment(SearchFragment())
                    true
                }

                else -> false
            }
        }
    }

    /**
     * Loads a given fragment into the fragment container.
     *
     * @param fragment The fragment to load.
     */
    private fun loadFragment(fragment: Fragment) {
        supportFragmentManager.beginTransaction()
            .replace(R.id.fragmentContainerView, fragment)
            .commit()
    }
}